pub struct WgpuContext {
pub window: Arc<Window>,
pub surface: Surface<'static>,
pub device: Device,
pub queue: Queue,
pub config: SurfaceConfiguration,
/* private fields */
}Expand description
WgpuContext stores all wgpu-related state for a single window application, including the device, queue, surface, surface configuration, and the window itself.
Fields
window: Arc<Window>surface: Surface<'static>device: Devicequeue: Queueconfig: SurfaceConfigurationImplementations
Sourceimpl WgpuContext
impl WgpuContext
pub fn new(window: Arc<Window>) -> WumeResult<Self>
pub fn resize(&mut self, width: u32, height: u32)
pub fn is_surface_configured(&self) -> bool
Sourcepub fn simple_frame<F>(&mut self, clear_color: Color, render_fn: F)where
F: FnOnce(&mut RenderPass<'_>),
pub fn simple_frame<F>(&mut self, clear_color: Color, render_fn: F)where
F: FnOnce(&mut RenderPass<'_>),
Sets up a simple render pass on the main surface with the given clear color, and calls the provided closure to perform rendering commands.